==> pennylane_sphinx_theme-0.4.2-py3-none-any.whl: pennylane_sphinx_theme/navbar.py <==
"""
This module contains the common PennyLane navigation bar data.
"""

NAVBAR_LEFT = [
    {
        "name": "Learn",
        "href": "https://pennylane.ai/qml/",
        "dropdown": [
            {
                "name": "Demos",
                "href": "https://pennylane.ai/qml/",
            },
            {
                "name": "Codebook",
                "href": "https://codebook.xanadu.ai/",
                "external": True,
            },
            {
                "name": "Challenges",
                "href": "https://pennylane.ai/challenges/",
            },
            {
                "name": "Videos",
                "href": "https://pennylane.ai/qml/videos/",
            },
            {
                "name": "Glossary",
                "href": "https://pennylane.ai/qml/glossary/",
            },
            {
                "name": "Education",
                "href": "https://pennylane.ai/education/",
            },
            # {
            #     "name": "Performance",
            #     "href": "https://pennylane.ai/performance/",
            # },
            {
                "name": "FAQ",
                "href": "https://pennylane.ai/faq/",
            },
        ],
    },
    {
        "name": "Documentation",
        "href": "https://docs.pennylane.ai",
        "dropdown": [
            {
                "name": "API",
                "href": "https://docs.pennylane.ai/en/stable/code/qml.html",
            },
            {
                "name": "Devices",
                "href": "https://pennylane.ai/plugins/",
            },
            {
                "name": "GitHub",
                "href": "https://github.com/PennyLaneAI/pennylane",
                "external": True,
            },
            {
                "name": "Catalyst",
                "href": "https://docs.pennylane.ai/projects/catalyst/",
            },
        ],
    },
    {
        "name": "Datasets",
        "href": "https://pennylane.ai/datasets/",
    },
    {
        "name": "Blog",
        "href": "https://pennylane.ai/blog/",
    },
    {
        "name": "Support",
        "href": "https://discuss.pennylane.ai",
        "external": True,
    },
]


NAVBAR_RIGHT = [
    {
        "name": "GitHub",
        "href": "https://github.com/PennyLaneAI/pennylane",
        "icon": "bx bxl-github",
    },
    {
        "name": "Install",
        "href": "https://pennylane.ai/install",
    },
]

==> pennylane_sphinx_theme-0.5.1-py3-none-any.whl: pennylane_sphinx_theme/navbar.py <==
"""
This module contains the common PennyLane navigation bar data.
"""

NAVBAR_LEFT = [
    {
        "name": "Learn",
        "href": "https://pennylane.ai/qml/",
        "dropdown": [
            {
                "name": "Demos",
                "href": "https://pennylane.ai/qml/",
            },
            {
                "name": "Codebook",
                "href": "https://codebook.xanadu.ai/",
                "external": True,
            },
            {
                "name": "Challenges",
                "href": "https://pennylane.ai/challenges/",
            },
            {
                "name": "Videos",
                "href": "https://pennylane.ai/qml/videos/",
            },
            {
                "name": "Glossary",
                "href": "https://pennylane.ai/qml/glossary/",
            },
            {
                "name": "Education",
                "href": "https://pennylane.ai/education/",
            },
            {
                "name": "Performance",
                "href": "https://pennylane.ai/performance/",
            },
            {
                "name": "FAQ",
                "href": "https://pennylane.ai/faq/",
            },
        ],
    },
    {
        "name": "Documentation",
        "href": "https://docs.pennylane.ai",
        "dropdown": [
            {
                "name": "API",
                "href": "https://docs.pennylane.ai/en/stable/code/qml.html",
            },
            {
                "name": "Devices",
                "href": "https://pennylane.ai/plugins/",
            },
            {
                "name": "GitHub",
                "href": "https://github.com/PennyLaneAI/pennylane",
                "external": True,
            },
            {
                "name": "Catalyst",
                "href": "https://docs.pennylane.ai/projects/catalyst/",
            },
        ],
    },
    {
        "name": "Datasets",
        "href": "https://pennylane.ai/datasets/",
    },
    {
        "name": "Blog",
        "href": "https://pennylane.ai/blog/",
    },
    {
        "name": "Support",
        "href": "https://discuss.pennylane.ai",
        "external": True,
    },
]


NAVBAR_RIGHT = [
    {
        "name": "GitHub",
        "href": "https://github.com/PennyLaneAI/pennylane",
        "icon": "bx bxl-github",
    },
    {
        "name": "Install",
        "href": "https://pennylane.ai/install",
    },
]
